@@ -39,22 +39,23 @@ def random_tcp_port():
 
 def create_ticket(uuid=None, ops=None, timeout=300, size=2**64,
                   url="file:///tmp/foo.img", transfer_id=None, filename=None,
-                  sparse=None, dirty=None):
+                  sparse=None, dirty=None, inactivity_timeout=120):
     d = {
         "uuid": uuid or str(uuid4()),
         "timeout": timeout,
         "ops": ["read", "write"] if ops is None else ops,
         "size": size,
         "url": url,
+        "transfer_id": transfer_id or str(uuid4()),
     }
-    if transfer_id is not None:
-        d["transfer_id"] = transfer_id
     if filename is not None:
         d["filename"] = filename
     if sparse is not None:
         d["sparse"] = sparse
     if dirty is not None:
         d["dirty"] = dirty
+    if inactivity_timeout is not None:
+        d["inactivity_timeout"] = inactivity_timeout
     return d
 
 
